@@ -176,6 +176,7 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade:
 
   m_Notebook_Find.signal_find_criteria.connect(sigc::mem_fun(*this, &Frame_Glom::on_notebook_find_criteria));
 
+  m_Notebook_Data.signal_record_details_requested().connect(sigc::mem_fun(*this, &Frame_Glom::on_notebook_data_record_details_requested));
   //Fill Composite View:
   //This means that set_document and load/save are delegated to these children:
   add_view(m_pBox_Tables);
@@ -564,12 +565,7 @@ void Frame_Glom::on_notebook_find_criteria(const Glib::ustring& strWhereClause)
 
     if(!records_found)
     {
-      Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("No Records Found")), true, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_NONE);
-      dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-      dialog.add_button(_("New Find"), Gtk::RESPONSE_OK);
-      dialog.set_secondary_text(_("Your find criteria did not match any records in the table."));
-      dialog.set_transient_for(*(get_app_window()));
-      bool find_again = dialog.run();
+      bool find_again = show_warning_no_records_found(*get_app_window());
 
       if(find_again)
         pApp->set_mode_find();
@@ -608,7 +604,7 @@ void Frame_Glom::show_table_title()
     else //Use the table name if there is no table title.
       table_label = m_strTableName;
 
-    m_pLabel_Table->set_text(table_label);
+    m_pLabel_Table->set_markup("<b><span size=\"xx-large\">" + table_label + "</span></b>"); //Show the table title in large text, because it's very important to the user.
   }
 }
 
@@ -1099,3 +1095,9 @@ void Frame_Glom::on_dialog_tables_hide()
   }
 }
 
+void Frame_Glom::on_notebook_data_record_details_requested(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value)
+{
+  show_table(table_name);
+  m_Notebook_Data.show_details(primary_key_value);
+}
+
