@@ -26,7 +26,8 @@
 #include <glibmm/i18n.h>
 
 Box_Data_List::Box_Data_List()
-: m_has_one_or_more_records(false)
+: m_has_one_or_more_records(false),
+  m_read_only(false)
 {
   m_layout_name = "list";
 
@@ -72,6 +73,25 @@ Box_Data_List::~Box_Data_List()
   remove_view(&m_AddDel);
 }
 
+void Box_Data_List::enable_buttons()
+{
+  const Privileges table_privs = get_current_privs(m_strTableName);
+  
+    //Enable/Disable record creation and deletion:
+  bool allow_create = !m_read_only;
+  bool allow_delete = !m_read_only;
+  if(!m_read_only)
+  {
+    allow_create = table_privs.m_create;
+    allow_delete = table_privs.m_delete;
+  }
+  
+  m_AddDel.set_allow_add(allow_create);
+  m_AddDel.set_allow_delete(allow_delete);
+  
+  m_AddDel.set_allow_view_details(table_privs.m_view);
+}
+
 bool Box_Data_List::fill_from_database()
 {
   bool result = false;
@@ -96,9 +116,7 @@ bool Box_Data_List::fill_from_database()
     //Do not try to show the data if the user may not view it:
     const Privileges table_privs = get_current_privs(m_strTableName);
 
-    //Enable/Disable record creation and deletion:
-    m_AddDel.set_allow_add(table_privs.m_create);
-    m_AddDel.set_allow_delete(table_privs.m_delete);
+    enable_buttons();
 
     m_AddDel.set_where_clause(m_strWhereClause);
 
@@ -128,8 +146,7 @@ bool Box_Data_List::fill_from_database()
 
 void Box_Data_List::on_adddel_user_requested_add()
 {
-g_warning("Box_Data_List::on_adddel_user_requested_add() start: m_FieldsShowns.size()=%d", m_FieldsShown.size());
-  if(m_FieldsShown.empty())
+ if(m_FieldsShown.empty())
     return; //Don't try to add a record to a list with no fields.
     
   Gtk::TreeModel::iterator iter = m_AddDel.get_item_placeholder();
@@ -172,8 +189,6 @@ g_warning("Box_Data_List::on_adddel_user_requested_add() start: m_FieldsShowns.s
       //g_warning("Box_Data_List::on_adddel_user_requested_add(): index_field_to_edit does not exist: %d", index_field_to_edit);
     }
   }
-  
-  g_warning("Box_Data_List::on_adddel_user_requested_add() end");
 }
 
 void Box_Data_List::on_adddel_user_requested_edit(const Gtk::TreeModel::iterator& row)
@@ -192,15 +207,7 @@ void Box_Data_List::on_adddel_user_requested_delete(const Gtk::TreeModel::iterat
 {
   if(rowStart)
   {
-    //Ask the user for confirmation:
-    Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Delete record")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE);
-    dialog.set_secondary_text(_("Are you sure that you would like to delete this record? The data in this record will then be permanently lost."));
-    dialog.set_transient_for(*get_app_window());
-    dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-    dialog.add_button(Gtk::Stock::DELETE, Gtk::RESPONSE_OK);
-
-    int response = dialog.run();
-    if(response == Gtk::RESPONSE_OK)
+    if(confirm_delete_record())
     {
       const Gnome::Gda::Value primary_key_value = get_primary_key_value(rowStart);
       record_delete(primary_key_value);
@@ -553,9 +560,11 @@ void Box_Data_List::on_details_nav_last()
     m_AddDel.select_item(iter);
     signal_user_requested_details().emit(m_AddDel.get_value_key_selected());
   }
+  else
+    signal_user_requested_details().emit(Gnome::Gda::Value()); //Show a blank record if there are no records.
 }
 
-void Box_Data_List::on_Details_record_deleted(Gnome::Gda::Value primary_key_value)
+void Box_Data_List::on_Details_record_deleted(const Gnome::Gda::Value& primary_key_value)
 {
   //Find out which row is affected:
   Gtk::TreeModel::iterator iter = m_AddDel.get_row(primary_key_value);
@@ -595,7 +604,28 @@ Gnome::Gda::Value Box_Data_List::get_primary_key_value(const Gtk::TreeModel::ite
 
 Gnome::Gda::Value Box_Data_List::get_primary_key_value_selected()
 {
-  return Gnome::Gda::Value(m_AddDel.get_value_key_selected());
+  return m_AddDel.get_value_key_selected();
+}
+
+Gnome::Gda::Value Box_Data_List::get_primary_key_value_first()
+{
+  Glib::RefPtr<Gtk::TreeModel> model = m_AddDel.get_model();
+  if(model)
+  {
+    Gtk::TreeModel::iterator iter = model->children().begin();
+    while(iter != model->children().end())
+    {
+      Gnome::Gda::Value value = get_primary_key_value(iter);
+      if(GlomConversions::value_is_empty(value))
+      {
+        ++iter;
+      }
+      else
+        return value;
+    }
+  }
+  
+  return Gnome::Gda::Value();
 }
 
 Gnome::Gda::Value Box_Data_List::get_entered_field_data(const LayoutItem_Field& field) const
@@ -647,9 +677,13 @@ void Box_Data_List::create_layout()
 
 
       //Add a column for each table field:
-      for(type_vecLayoutFields::const_iterator iter = m_FieldsShown.begin(); iter != m_FieldsShown.end(); ++iter)
+      for(type_vecLayoutFields::iterator iter = m_FieldsShown.begin(); iter != m_FieldsShown.end(); ++iter)
       {
-        m_AddDel.add_column(*(*iter));
+        sharedptr<LayoutItem_Field> field = *iter;
+        if(m_read_only)
+          field->set_editable(false);
+          
+        m_AddDel.add_column(*field);
       }
 
       m_AddDel.set_where_clause(m_strWhereClause);
@@ -737,4 +771,18 @@ void Box_Data_List::print_layout_group(xmlpp::Element* /* node_parent */, const
 {
 }
 
+void Box_Data_List::set_read_only(bool read_only)
+{
+  //This is useful when showing find results for the user to select one, without changing them.
+  m_read_only = read_only;
+  m_AddDel.set_allow_add(!read_only);
+  m_AddDel.set_allow_delete(!read_only);
+}
+
+void Box_Data_List::set_open_button_title(const Glib::ustring& title)
+{
+  m_AddDel.set_open_button_title(title);
+}
+
+
 
