@@ -19,6 +19,7 @@
  */
 
 #include "notebook_data.h"
+#include "../data_structure/glomconversions.h"
 #include <glibmm/i18n.h>
 
 Notebook_Data::Notebook_Data()
@@ -35,10 +36,6 @@ Notebook_Data::Notebook_Data()
 
   //Allow List to ask Details to show a record.
   m_Box_List.signal_user_requested_details().connect(sigc::mem_fun(*this, &Notebook_Data::on_list_user_requested_details));
-
-  //Allow Details's Related Records to ask Details to show a record.
-  //m_Box_Details.signal_user_requested_related_details().connect(sigc::mem_fun(*this, &Notebook_Data::on_Details_user_requested_related_details));
-
     
   //Allow Details to ask List to ask Details to show a different record:
   m_Box_Details.signal_nav_first().connect(sigc::mem_fun(m_Box_List, &Box_Data_List::on_details_nav_first));
@@ -49,6 +46,9 @@ Notebook_Data::Notebook_Data()
   //Allow Details to tell List about record deletion:
   m_Box_Details.signal_record_deleted().connect(sigc::mem_fun(m_Box_List, &Box_Data_List::on_Details_record_deleted));
 
+  //Allow Details to ask to show a different record in a different table:
+  m_Box_Details.signal_requested_related_details().connect(sigc::mem_fun(*this, &Notebook_Data::on_Details_user_requested_related_details));
+
   //Fill composite view:
   add_view(&m_Box_List);
   add_view(&m_Box_Details);
@@ -64,6 +64,8 @@ Notebook_Data::~Notebook_Data()
 
 bool Notebook_Data::init_db_details(const Glib::ustring& strTableName, const Glib::ustring& strWhereClause)
 {
+  m_table_name = strTableName;
+
   bool result = false;
   //strWhereClause is only used as a result of a find.
 
@@ -72,29 +74,80 @@ bool Notebook_Data::init_db_details(const Glib::ustring& strTableName, const Gli
   {
     sharedptr<SharedConnection> sharedconnection = connect_to_server();
 
-    result = m_Box_List.init_db_details(strTableName, strWhereClause);
-    m_Box_Details.init_db_details(strTableName, m_Box_List.get_primary_key_value_selected());
+    result = m_Box_List.init_db_details(m_table_name, strWhereClause);
+    //m_Box_List.load_from_document();
+    
+    //Show the previously-shown record, if there is one,
+    //so that returning to this table will return the user to the same record:
+    Document_Glom* document = get_document();
+    if(document)
+    {
+      Gnome::Gda::Value primary_key_for_details = document->get_layout_record_viewed(m_table_name, m_Box_Details.get_layout_name());
+      
+      if(GlomConversions::value_is_empty(primary_key_for_details))
+      {
+        //Make sure that the details view is not empty, if there are any records to show:
+        primary_key_for_details = m_Box_List.get_primary_key_value_selected();
+        if(GlomConversions::value_is_empty(primary_key_for_details))
+          primary_key_for_details = m_Box_List.get_primary_key_value_first();
+      }
+      
+       m_Box_Details.init_db_details(m_table_name, primary_key_for_details);
+    }
   }
 
-  //Select List as default:
-  set_current_page(m_iPage_List);
+  //Select the last-viewed layout:
+  bool found = false;
+  Document_Glom* document = get_document();
+  if(document)
+  {
+    const Glib::ustring current_layout = get_document()->get_layout_current(m_table_name);
+    if(!current_layout.empty())
+    {
+      const int count = get_n_pages();
+      int page = 0;
+      while(!found && (page < count))
+      {
+        Box_Data* box = dynamic_cast<Box_Data*>(get_nth_page(page));
+        if(box && (box->get_layout_name() == current_layout))
+          found = true;
+        else
+          ++page;
+      }
+      
+      if(found)
+      {
+        set_current_page(page);
+      }
+    }
+  }
+  
+  if(!found)
+  {   
+    //Select List as default:
+    set_current_page(m_iPage_List);
+  }
 
   return result;
 }
 
-void Notebook_Data::on_list_user_requested_details(Gnome::Gda::Value primary_key_value)
+void Notebook_Data::on_list_user_requested_details(const Gnome::Gda::Value& primary_key_value)
 {
   m_Box_Details.refresh_data_from_database(primary_key_value);
   set_current_page(m_iPage_Details);
 }
 
-void Notebook_Data::on_Details_user_requested_related_details(Glib::ustring strTableName, Gnome::Gda::Value primary_key_value)
+void Notebook_Data::on_Details_user_requested_related_details(const Glib::ustring& strTableName, Gnome::Gda::Value primary_key_value)
 {
+  signal_record_details_requested().emit(strTableName, primary_key_value);
+  
+  /*
   //Show a different table:
-  init_db_details(strTableName);
+  init_db_details(m_table_name);
 
   //Show the specific record:
   on_list_user_requested_details(primary_key_value);
+  */
 }
 
 void Notebook_Data::select_page_for_find_results()
@@ -152,3 +205,28 @@ Notebook_Data::dataview Notebook_Data::get_current_view() const
   return result;
 }
 
+Notebook_Data::type_signal_record_details_requested Notebook_Data::signal_record_details_requested()
+{
+  return m_signal_record_details_requested;
+}
+
+void Notebook_Data::show_details(const Gnome::Gda::Value& primary_key_value)
+{
+  //Reuse this implementation:
+  on_list_user_requested_details(primary_key_value);
+}
+
+void Notebook_Data::on_switch_page_handler(GtkNotebookPage* pPage, guint uiPageNumber)
+{
+  //Call base class:
+  Notebook_Glom::on_switch_page_handler(pPage, uiPageNumber);
+  
+  //Remember that currently-viewed layout, so we can show it again when the user comes back to this table from elsewhere:
+  Box_Data* box = dynamic_cast<Box_Data*>(get_nth_page(uiPageNumber));
+  if(box)
+  {
+    Document_Glom* document = get_document();
+    if(document)
+      document->set_layout_current(m_table_name, box->get_layout_name());
+  }
+}
