@@ -28,6 +28,8 @@ class Box_Data_Details_Find : public Box_Data_Details
 public: 
   Box_Data_Details_Find();
   virtual ~Box_Data_Details_Find();
+  
+  virtual bool init_db_details(const Glib::ustring& table_name);
 
   virtual Gtk::Widget* get_default_button(); //override
     
@@ -36,8 +38,7 @@ protected:
   virtual bool fill_from_database(); //override.
   virtual void fill_related(); //override.
 
-  virtual void on_adddel_user_changed(guint row, guint col); //override
-
+  virtual void on_flowtable_field_edited(const LayoutItem_Field& id, const Gnome::Gda::Value& value);
 
 };
 
