@@ -29,6 +29,7 @@
 #include "../document/document_glom.h"
 #include "../mode_data/box_data_list_related.h"
 #include "layoutwidgetbase.h"
+#include "../mode_data/treestore_layout.h" //Forthe enum.
 #include <map>
 #include <list>
 
@@ -59,7 +60,6 @@ public:
   virtual void add_layout_item(const LayoutItem& group);
   virtual void add_layout_group(const LayoutGroup& group);
 
-
   virtual void set_field_editable(const LayoutItem_Field& field, bool editable = true);
 
   virtual Gnome::Gda::Value get_field_value(const LayoutItem_Field& field) const;
@@ -90,7 +90,24 @@ public:
    */
   typedef sigc::signal<void, const LayoutItem_Field&, const Gnome::Gda::Value&> type_signal_field_edited;
   type_signal_field_edited signal_field_edited();
+  
+  /** For instance,
+   * void on_flowtable_field_open_details_requested(const LayoutItem_Field& field, const Gnome::Gda::Value& value);
+   */
+  typedef sigc::signal<void, const LayoutItem_Field&, const Gnome::Gda::Value&> type_signal_field_open_details_requested;
+  type_signal_field_open_details_requested signal_field_open_details_requested();
 
+  /** For instance,
+   * void on_related_record_changed(const Glib::ustring& relationship_name);
+   */
+  typedef sigc::signal<void, const Glib::ustring&> type_signal_related_record_changed;
+  type_signal_related_record_changed signal_related_record_changed();
+  
+  /** For instance,
+   * void on_requested_related_details(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value);-
+   */
+  typedef sigc::signal<void, const Glib::ustring&, Gnome::Gda::Value> type_signal_requested_related_details;
+  type_signal_requested_related_details signal_requested_related_details();
 
 protected:
 
@@ -100,14 +117,24 @@ protected:
   ///Get portals whose relationships have @a from_key as the from_key.
   virtual type_list_widgets get_portals(const LayoutItem_Field& from_key);
 
-  int get_suitable_width(Field::glom_field_type field_type);
+  //int get_suitable_width(Field::glom_field_type field_type);
+
   void on_entry_edited(const Gnome::Gda::Value& value,  LayoutItem_Field field);
+  void on_entry_open_details_requested(const Gnome::Gda::Value& value, LayoutItem_Field field);
   void on_flowtable_entry_edited(const LayoutItem_Field& field, const Gnome::Gda::Value& value);
+  void on_flowtable_entry_open_details_requested(const LayoutItem_Field& field, const Gnome::Gda::Value& value); 
+
+  void on_portal_record_changed(const Glib::ustring& relationship_name);
+  void on_flowtable_related_record_changed(const Glib::ustring& relationship_name);
+  void on_flowtable_requested_related_details(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value);
 
   /// Remember the layout widget so we can iterate through them later.
-  void add_layoutwidgetbase(LayoutWidgetBase* layout_widget);
   void on_layoutwidget_changed();
 
+  void on_datawidget_layout_item_added(TreeStore_Layout::enumType item_type, DataWidget* pDataWidget);
+
+  void on_portal_user_requested_details(Gnome::Gda::Value primary_key_value, Box_Data_List_Related* portal_box);
+
   class Info
   {
   public:
@@ -135,9 +162,20 @@ protected:
   typedef std::list< LayoutWidgetBase* > type_list_layoutwidgets;
   type_list_layoutwidgets m_list_layoutwidgets;
 
+  void add_field_at_position(const LayoutItem_Field& layoutitem_field, const Glib::ustring& table_name, const type_list_layoutwidgets::iterator& add_before);
+  void add_layoutwidgetbase(LayoutWidgetBase* layout_widget);
+  void add_layoutwidgetbase(LayoutWidgetBase* layout_widget, const type_list_layoutwidgets::iterator& add_before);
+  void add_layout_item_at_position(const LayoutItem& item, const type_list_layoutwidgets::iterator& add_before);
+  void add_layout_group_at_position(const LayoutGroup& group, const type_list_layoutwidgets::iterator& add_before);
+
   Glib::ustring m_table_name;
 
   type_signal_field_edited m_signal_field_edited;
+  type_signal_field_open_details_requested m_signal_field_open_details_requested;
+
+  //type_signal_related_record_added m_signal_related_record_added;
+  type_signal_related_record_changed m_signal_related_record_changed;
+  type_signal_requested_related_details m_signal_requested_related_details;
 };
 
 
